==> tuia-advert-center-api-1.5.0-20180628.022437-50-sources.jar: cn/com/duiba/tuia/core/api/dto/statistics/AdvertMaterialPromoteStatisticDto.java <==
package cn.com.duiba.tuia.core.api.dto.statistics;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

import java.math.BigDecimal;
import java.util.Date;

/**广告－素材－落地页回流数据统计返回参数虚体
 * Created by jzl on 18/5/20.
 */
public class AdvertMaterialPromoteStatisticDto extends BaseDto {

    /** 落地页名称**/
    private String name;

    /**落地页ID**/
    private Long promoteId;

    /**日期 例如：2018-05-16**/
    private Date curDate;

    /**广告id**/
    private Long advertId;

    /**广告名称**/
    private String advertName;

    /**素材id**/
    private Long material;

    /**落地页url**/
    private String promoteUrl;

    /**消耗**/
    private Long consumeTotal;

    /**消耗 转化成元 单位**/
    private BigDecimal consumeTotalDecimal;

    /**发券量**/
    private Long coupons;

    /**计费点击PV**/
    private Long efClickPv;

    /**计费点击UV**/
    private Long efClickUv;

    /**计费点击率**/
    private String efClickRadio;

    /**转化PV**/
    private Long efPv;

    /**转化UV**/
    private Long efUv;

    /**转化成本（PV）**/
    private BigDecimal efConsume;

    /**CVR**/
    private String cvr;

    /**计费点击均价**/
    private BigDecimal consumeAvg;

    /**安装PV**/
    private Long installPv;

    /**安装UV**/
    private Long installUv;

    /**安装成本（UV）**/
    private BigDecimal installConsume;

    /**APP启动PV**/
    private Long startPv;

    /**APP启动UV**/
    private Long startUv;

    /**APP启动成本**/
    private BigDecimal startConsume;

    /**注册PV**/
    private Long registePv;

    /**注册UV**/
    private Long registeUv;

    /**注册成本**/
    private BigDecimal registeConsume;

    /**激活PV**/
    private Long activatePv;

    /**激活UV**/
    private Long activateUv;

    /**激活成本（UV）**/
    private BigDecimal activateConsume;

    /**登录PV**/
    private Long loginPv;

    /**登录UV**/
    private Long loginUv;

    /**登录成本（UV）**/
    private BigDecimal loginConsume;

    /**付费PV**/
    private Long payPv;

    /**付费UV**/
    private Long payUv;

    /**付费成本（UV）**/
    private BigDecimal payConsume;

    /**落地页访问PV**/
    private Long promoteVisitPv;

    /**落地页访问UV**/
    private Long promoteVisitUv;

    /**落地页到达率**/
    private String promoteVisitConsume;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getPromoteId() {
        return promoteId;
    }

    public void setPromoteId(Long promoteId) {
        this.promoteId = promoteId;
    }

    public Long getPromoteVisitPv() {
        return promoteVisitPv;
    }

    public void setPromoteVisitPv(Long promoteVisitPv) {
        this.promoteVisitPv = promoteVisitPv;
    }

    public Long getPromoteVisitUv() {
        return promoteVisitUv;
    }

    public void setPromoteVisitUv(Long promoteVisitUv) {
        this.promoteVisitUv = promoteVisitUv;
    }

    public String getPromoteVisitConsume() {
        return promoteVisitConsume;
    }

    public void setPromoteVisitConsume(String promoteVisitConsume) {
        this.promoteVisitConsume = promoteVisitConsume;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getMaterial() {
        return material;
    }

    public void setMaterial(Long material) {
        this.material = material;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public Long getConsumeTotal() {
        return consumeTotal;
    }

    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    public Long getCoupons() {
        return coupons;
    }

    public void setCoupons(Long coupons) {
        this.coupons = coupons;
    }

    public Long getEfClickPv() {
        return efClickPv;
    }

    public void setEfClickPv(Long efClickPv) {
        this.efClickPv = efClickPv;
    }

    public Long getEfClickUv() {
        return efClickUv;
    }

    public void setEfClickUv(Long efClickUv) {
        this.efClickUv = efClickUv;
    }

    public String getEfClickRadio() {
        return efClickRadio;
    }

    public void setEfClickRadio(String efClickRadio) {
        this.efClickRadio = efClickRadio;
    }

    public Long getEfPv() {
        return efPv;
    }

    public void setEfPv(Long efPv) {
        this.efPv = efPv;
    }

    public Long getEfUv() {
        return efUv;
    }

    public void setEfUv(Long efUv) {
        this.efUv = efUv;
    }

    public BigDecimal getEfConsume() {
        return efConsume;
    }

    public void setEfConsume(BigDecimal efConsume) {
        this.efConsume = efConsume;
    }

    public String getCvr() {
        return cvr;
    }

    public void setCvr(String cvr) {
        this.cvr = cvr;
    }

    public BigDecimal getConsumeAvg() {
        return consumeAvg;
    }

    public void setConsumeAvg(BigDecimal consumeAvg) {
        this.consumeAvg = consumeAvg;
    }

    public Long getInstallPv() {
        return installPv;
    }

    public void setInstallPv(Long installPv) {
        this.installPv = installPv;
    }

    public Long getInstallUv() {
        return installUv;
    }

    public void setInstallUv(Long installUv) {
        this.installUv = installUv;
    }

    public BigDecimal getInstallConsume() {
        return installConsume;
    }

    public void setInstallConsume(BigDecimal installConsume) {
        this.installConsume = installConsume;
    }

    public Long getStartPv() {
        return startPv;
    }

    public void setStartPv(Long startPv) {
        this.startPv = startPv;
    }

    public Long getStartUv() {
        return startUv;
    }

    public void setStartUv(Long startUv) {
        this.startUv = startUv;
    }

    public BigDecimal getStartConsume() {
        return startConsume;
    }

    public void setStartConsume(BigDecimal startConsume) {
        this.startConsume = startConsume;
    }

    public Long getRegistePv() {
        return registePv;
    }

    public void setRegistePv(Long registePv) {
        this.registePv = registePv;
    }

    public Long getRegisteUv() {
        return registeUv;
    }

    public void setRegisteUv(Long registeUv) {
        this.registeUv = registeUv;
    }

    public BigDecimal getRegisteConsume() {
        return registeConsume;
    }

    public void setRegisteConsume(BigDecimal registeConsume) {
        this.registeConsume = registeConsume;
    }

    public Long getActivatePv() {
        return activatePv;
    }

    public void setActivatePv(Long activatePv) {
        this.activatePv = activatePv;
    }

    public Long getActivateUv() {
        return activateUv;
    }

    public void setActivateUv(Long activateUv) {
        this.activateUv = activateUv;
    }

    public BigDecimal getActivateConsume() {
        return activateConsume;
    }

    public void setActivateConsume(BigDecimal activateConsume) {
        this.activateConsume = activateConsume;
    }

    public Long getLoginPv() {
        return loginPv;
    }

    public void setLoginPv(Long loginPv) {
        this.loginPv = loginPv;
    }

    public Long getLoginUv() {
        return loginUv;
    }

    public void setLoginUv(Long loginUv) {
        this.loginUv = loginUv;
    }

    public BigDecimal getLoginConsume() {
        return loginConsume;
    }

    public void setLoginConsume(BigDecimal loginConsume) {
        this.loginConsume = loginConsume;
    }

    public Long getPayPv() {
        return payPv;
    }

    public void setPayPv(Long payPv) {
        this.payPv = payPv;
    }

    public Long getPayUv() {
        return payUv;
    }

    public void setPayUv(Long payUv) {
        this.payUv = payUv;
    }

    public BigDecimal getPayConsume() {
        return payConsume;
    }

    public void setPayConsume(BigDecimal payConsume) {
        this.payConsume = payConsume;
    }

    public BigDecimal getConsumeTotalDecimal() {
        return consumeTotalDecimal;
    }

    public void setConsumeTotalDecimal(BigDecimal consumeTotalDecimal) {
        this.consumeTotalDecimal = consumeTotalDecimal;
    }
}

==> tuia-advert-center-api-1.7.7-sources.jar: cn/com/duiba/tuia/core/api/dto/statistics/AdvertMaterialPromoteStatisticDto.java <==
package cn.com.duiba.tuia.core.api.dto.statistics;

import java.math.BigDecimal;
import java.util.Date;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

/**广告－素材－落地页回流数据统计返回参数虚体
 * Created by jzl on 18/5/20.
 */
public class AdvertMaterialPromoteStatisticDto extends BaseDto {

    private static final long serialVersionUID = -5699436649196852627L;
    /** 落地页名称**/
    private String name;

    /**落地页ID**/
    private Long promoteId;

    /**日期 例如：2018-05-16**/
    private Date curDate;

    /**广告id**/
    private Long advertId;

    /**广告名称**/
    private String advertName;

    /**素材id**/
    private Long material;

    /**落地页url**/
    private String promoteUrl;

    /**消耗**/
    private Long consumeTotal;

    /**消耗 转化成元 单位**/
    private BigDecimal consumeTotalDecimal;

    /**发券量**/
    private Long coupons;

    /**计费点击PV**/
    private Long efClickPv;

    /**计费点击UV**/
    private Long efClickUv;

    /**计费点击率**/
    private String efClickRadio;

    /**转化PV**/
    private Long efPv;

    /**转化UV**/
    private Long efUv;

    /**转化成本（PV）**/
    private BigDecimal efConsume;

    /**CVR**/
    private String cvr;

    /**计费点击均价**/
    private BigDecimal consumeAvg;

    /**安装PV**/
    private Long installPv;

    /**安装UV**/
    private Long installUv;

    /**安装成本（UV）**/
    private BigDecimal installConsume;

    /**APP启动PV**/
    private Long startPv;

    /**APP启动UV**/
    private Long startUv;

    /**APP启动成本**/
    private BigDecimal startConsume;

    /**注册PV**/
    private Long registePv;

    /**注册UV**/
    private Long registeUv;

    /**注册成本**/
    private BigDecimal registeConsume;

    /**激活PV**/
    private Long activatePv;

    /**激活UV**/
    private Long activateUv;

    /**激活成本（UV）**/
    private BigDecimal activateConsume;

    /**登录PV**/
    private Long loginPv;

    /**登录UV**/
    private Long loginUv;

    /**登录成本（UV）**/
    private BigDecimal loginConsume;

    /**付费PV**/
    private Long payPv;

    /**付费UV**/
    private Long payUv;

    /**付费成本（UV）**/
    private BigDecimal payConsume;

    /**落地页访问PV**/
    private Long promoteVisitPv;

    /**落地页访问UV**/
    private Long promoteVisitUv;

    /**落地页到达率**/
    private String promoteVisitConsume;

    /** 进件pv */
    private Long              entryPv;

    /** 进件uv */
    private Long              entryUv;

    /** 进件成本 */
    private BigDecimal        entryCost;

    /** 完件的pv */
    private Long              finishPv;

    /** 完件的uv */
    private Long              finishUv;

    /** 完件成本 */
    private BigDecimal        finishCost;

    /** 签收的Pv */
    private Long              signPv;

    /** 签收的Uv */
    private Long              signUv;

    /** 签收成本 */
    private BigDecimal        signCost;

    /** 拒签的Pv */
    private Long              denyPv;

    /** 拒签的Uv */
    private Long              denyUv;

    /** 拒签成本 */
    private BigDecimal        denyCost;


    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getPromoteId() {
        return promoteId;
    }

    public void setPromoteId(Long promoteId) {
        this.promoteId = promoteId;
    }

    public Long getPromoteVisitPv() {
        return promoteVisitPv;
    }

    public void setPromoteVisitPv(Long promoteVisitPv) {
        this.promoteVisitPv = promoteVisitPv;
    }

    public Long getPromoteVisitUv() {
        return promoteVisitUv;
    }

    public void setPromoteVisitUv(Long promoteVisitUv) {
        this.promoteVisitUv = promoteVisitUv;
    }

    public String getPromoteVisitConsume() {
        return promoteVisitConsume;
    }

    public void setPromoteVisitConsume(String promoteVisitConsume) {
        this.promoteVisitConsume = promoteVisitConsume;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getMaterial() {
        return material;
    }

    public void setMaterial(Long material) {
        this.material = material;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public Long getConsumeTotal() {
        return consumeTotal;
    }

    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    public Long getCoupons() {
        return coupons;
    }

    public void setCoupons(Long coupons) {
        this.coupons = coupons;
    }

    public Long getEfClickPv() {
        return efClickPv;
    }

    public void setEfClickPv(Long efClickPv) {
        this.efClickPv = efClickPv;
    }

    public Long getEfClickUv() {
        return efClickUv;
    }

    public void setEfClickUv(Long efClickUv) {
        this.efClickUv = efClickUv;
    }

    public String getEfClickRadio() {
        return efClickRadio;
    }

    public void setEfClickRadio(String efClickRadio) {
        this.efClickRadio = efClickRadio;
    }

    public Long getEfPv() {
        return efPv;
    }

    public void setEfPv(Long efPv) {
        this.efPv = efPv;
    }

    public Long getEfUv() {
        return efUv;
    }

    public void setEfUv(Long efUv) {
        this.efUv = efUv;
    }

    public BigDecimal getEfConsume() {
        return efConsume;
    }

    public void setEfConsume(BigDecimal efConsume) {
        this.efConsume = efConsume;
    }

    public String getCvr() {
        return cvr;
    }

    public void setCvr(String cvr) {
        this.cvr = cvr;
    }

    public BigDecimal getConsumeAvg() {
        return consumeAvg;
    }

    public void setConsumeAvg(BigDecimal consumeAvg) {
        this.consumeAvg = consumeAvg;
    }

    public Long getInstallPv() {
        return installPv;
    }

    public void setInstallPv(Long installPv) {
        this.installPv = installPv;
    }

    public Long getInstallUv() {
        return installUv;
    }

    public void setInstallUv(Long installUv) {
        this.installUv = installUv;
    }

    public BigDecimal getInstallConsume() {
        return installConsume;
    }

    public void setInstallConsume(BigDecimal installConsume) {
        this.installConsume = installConsume;
    }

    public Long getStartPv() {
        return startPv;
    }

    public void setStartPv(Long startPv) {
        this.startPv = startPv;
    }

    public Long getStartUv() {
        return startUv;
    }

    public void setStartUv(Long startUv) {
        this.startUv = startUv;
    }

    public BigDecimal getStartConsume() {
        return startConsume;
    }

    public void setStartConsume(BigDecimal startConsume) {
        this.startConsume = startConsume;
    }

    public Long getRegistePv() {
        return registePv;
    }

    public void setRegistePv(Long registePv) {
        this.registePv = registePv;
    }

    public Long getRegisteUv() {
        return registeUv;
    }

    public void setRegisteUv(Long registeUv) {
        this.registeUv = registeUv;
    }

    public BigDecimal getRegisteConsume() {
        return registeConsume;
    }

    public void setRegisteConsume(BigDecimal registeConsume) {
        this.registeConsume = registeConsume;
    }

    public Long getActivatePv() {
        return activatePv;
    }

    public void setActivatePv(Long activatePv) {
        this.activatePv = activatePv;
    }

    public Long getActivateUv() {
        return activateUv;
    }

    public void setActivateUv(Long activateUv) {
        this.activateUv = activateUv;
    }

    public BigDecimal getActivateConsume() {
        return activateConsume;
    }

    public void setActivateConsume(BigDecimal activateConsume) {
        this.activateConsume = activateConsume;
    }

    public Long getLoginPv() {
        return loginPv;
    }

    public void setLoginPv(Long loginPv) {
        this.loginPv = loginPv;
    }

    public Long getLoginUv() {
        return loginUv;
    }

    public void setLoginUv(Long loginUv) {
        this.loginUv = loginUv;
    }

    public BigDecimal getLoginConsume() {
        return loginConsume;
    }

    public void setLoginConsume(BigDecimal loginConsume) {
        this.loginConsume = loginConsume;
    }

    public Long getPayPv() {
        return payPv;
    }

    public void setPayPv(Long payPv) {
        this.payPv = payPv;
    }

    public Long getPayUv() {
        return payUv;
    }

    public void setPayUv(Long payUv) {
        this.payUv = payUv;
    }

    public BigDecimal getPayConsume() {
        return payConsume;
    }

    public void setPayConsume(BigDecimal payConsume) {
        this.payConsume = payConsume;
    }

    public BigDecimal getConsumeTotalDecimal() {
        return consumeTotalDecimal;
    }

    public void setConsumeTotalDecimal(BigDecimal consumeTotalDecimal) {
        this.consumeTotalDecimal = consumeTotalDecimal;
    }

    public Long getEntryPv() {
        return entryPv;
    }

    public void setEntryPv(Long entryPv) {
        this.entryPv = entryPv;
    }

    public Long getEntryUv() {
        return entryUv;
    }

    public void setEntryUv(Long entryUv) {
        this.entryUv = entryUv;
    }

    public Long getFinishPv() {
        return finishPv;
    }

    public void setFinishPv(Long finishPv) {
        this.finishPv = finishPv;
    }

    public Long getFinishUv() {
        return finishUv;
    }

    public void setFinishUv(Long finishUv) {
        this.finishUv = finishUv;
    }

    public Long getSignPv() {
        return signPv;
    }

    public void setSignPv(Long signPv) {
        this.signPv = signPv;
    }

    public Long getSignUv() {
        return signUv;
    }

    public void setSignUv(Long signUv) {
        this.signUv = signUv;
    }

    public Long getDenyPv() {
        return denyPv;
    }

    public void setDenyPv(Long denyPv) {
        this.denyPv = denyPv;
    }

    public Long getDenyUv() {
        return denyUv;
    }

    public void setDenyUv(Long denyUv) {
        this.denyUv = denyUv;
    }

    public BigDecimal getEntryCost() {
        return entryCost;
    }

    public void setEntryCost(BigDecimal entryCost) {
        this.entryCost = entryCost;
    }

    public BigDecimal getFinishCost() {
        return finishCost;
    }

    public void setFinishCost(BigDecimal finishCost) {
        this.finishCost = finishCost;
    }

    public BigDecimal getSignCost() {
        return signCost;
    }

    public void setSignCost(BigDecimal signCost) {
        this.signCost = signCost;
    }

    public BigDecimal getDenyCost() {
        return denyCost;
    }

    public void setDenyCost(BigDecimal denyCost) {
        this.denyCost = denyCost;
    }
}
